import React, { useCallback, useEffect, useMemo, useRef } from 'react'
import Taro from '@tarojs/taro'
import { View, Canvas } from '@tarojs/components'
import CodeText from './CodeText'
import { code128 } from './drawCode'
import './style.less'

export default (props) => {
  const { code, height, codeVisible = true } = props

  // 使用 createSelectorQuery 有个注意点, id 或者 class 不能以数字开头
  const id = useMemo(() => `canvas-${Math.random().toString(36).substring(2, 10)}`, [])
  // const canvasRef = useRef()
  // const ctxRef = useRef()

  const style = useMemo(() => {
    return {
      height: `${height}px`,
      zIndex: 0,
    }
  }, [height])

  const renderBarCode = useCallback(() => {
    const query = Taro.createSelectorQuery()
    query.select(`#${id}`).fields({ node: true, size: true }).exec((res) => {
      if (!res[0]) return;
      const { node: canvas, width: w, height: h } = res[0]
      const ctx = canvas.getContext('2d')
      canvas.width = w
      canvas.height = h

      // canvasRef.current = canvas;
      // ctxRef.current = ctx;

      if (code) {
        code128(ctx, code, w, h);
      }
    })
  }, [code, id])

  useEffect(() => {
    Taro.nextTick(renderBarCode)
  }, [renderBarCode])

  return (
    <View className='barcode-box'>
      <Canvas style={style} type='2d' id={id}></Canvas>
      {
        codeVisible && <CodeText code={code} />
      }
      {
        !code && <View className='no-barcode'>暂无条码</View>
      }
    </View>
  )
}
