import { useEffect, useState } from 'react';
import dayjs from 'dayjs';
import { View } from '@tarojs/components'
import { PowerScrollView, Empty } from '@antmjs/vantui';
import { useModel } from '@/store';
import { getBarcode } from '@/services/user';
import Item from './Item';

import './style.less'

export default (props) => {
  const { person } = useModel('userData')
  const [list, setList] = useState([])

  useEffect(() => {
    if (person && person.personId) {
      const today = dayjs()
      const params = {
        startDate: today.subtract(7, 'day').format('YYYY-MM-DD'),
        endDate: today.format('YYYY-MM-DD'),
        idNo: person.idNo,
      }

      getBarcode(person.personId, params).then((res) => {
        if (!res) {
          setList([])
        } else {
          setList(JSON.parse(res))
        }
      }).catch(err => {
        console.error(err)
      })
    }
  }, [person])

  if (!list || !list.length) {
    <Empty description='暂无数据' />
  }

  return (
    <PowerScrollView
      className='barcode-history-list'
      refresherEnabled={false}
      total={list.length}
    >
      {
        list.map((barData, inx) => (
          <Item key={inx} person={person} barData={barData} />
        ))
      }
    </PowerScrollView>
  )
}
