import { View } from '@tarojs/components'
import { useEffect, useState } from 'react'
import dayjs from 'dayjs';
import { Button, Dialog, Tabs, Tab } from "@antmjs/vantui";
import { useModel } from '@/store';
import { getBarcode } from '@/services/user';
import Taro from '@tarojs/taro';
import BarCode from '@/components/barcode'
import Back from './components/Back';
import Main from './components/Main';
import Header from './components/Header';
import QRBox from './components/QRBox';
import QRItem from './components/QRItem';
import Footer from './components/Footer';

import './style.less'

const color = '#03737b'

const tabTitleStyle = {
  fontSize: '36rpx'
}

const borderBtnStyle = {
  border: `1px solid ${color}`,
  backgroundColor: 'transparent',
}

export default (props) => {
  const { person, user } = useModel('userData')
  const [barData, setBarData] = useState({})
  const [idCardVisible, setIdCardVisible] = useState(false)

  const goUserInfo = () => {
    Taro.navigateTo({
      url: '/pages/setUserInfo/index'
    })
  }

  const toHistory = () => {
    Taro.navigateTo({
      url: '/pages/History/index'
    })
  }

  const handleShowEditor = () => {
    setIdCardVisible(false)
    goUserInfo()
  }

  useEffect(() => {
    if (person && person.personId) {
      const params = {
        createDate: dayjs().subtract(1, 'day').format('YYYY-MM-DD'),
        idNo: person.idNo,
      }
      getBarcode(person.personId, params).then((res) => {
        if (typeof res === 'string') {
          const resp = JSON.parse(res) || {}
          setBarData(resp)
        } else {
          setBarData(res || {})
        }
      })
    }
  }, [person])

  useEffect(() => {
    if (user && user.userId) {
      if (!person || !person.idNo) {
        setIdCardVisible(true)
      } else {
        setIdCardVisible(false)
      }
    }
  }, [user, person])

  return (
    <View className='index-page'>
      <Back />
      <Main>
        <Header person={person} onEdit={goUserInfo} />
        <QRBox style={{ marginTop: '1.6em' }}>
          <Tabs lineHeight={2} lineWidth={120} color={color} titleActiveColor={color}>
            <Tab title='条码' titleStyle={tabTitleStyle}>
              <QRItem barData={barData}>
                <BarCode ratio={0.7} height={80} code={barData.barcode} />
              </QRItem>
            </Tab>
            <Tab title='身份码' titleStyle={tabTitleStyle}>
              <QRItem>
                <BarCode ratio={0.7} height={80} code={person?.idNo} />
              </QRItem>
            </Tab>
          </Tabs>
        </QRBox>
        <Button
          plain
          block
          size='large'
          color={color}
          style={{ marginTop: '1em', ...borderBtnStyle }}
          onClick={toHistory}
        >查看历史记录</Button>
        <Dialog title='提示' message='未添加个人信息' show={idCardVisible} onConfirm={handleShowEditor} />
        <Footer />
      </Main>
    </View>
  )
}




